@@ -4,6 +4,11 @@
 // @require       utils.js
 // ==/UserScript==
 
+// This placeholder gets munged with real data at build time.
+var WebappsGettextDict = JSON.parse(unescape(
+    "%7B%22GETTEXT%22%3A%22PLACEHOLDER%22%7D"
+));
+
 window.Unity = external.getUnityObject(1);
 
 function getComposeMessageNode() {
@@ -40,7 +45,7 @@ function messagingIndicatorSetup() {
         launchClickEvent(compose);
     }
     Unity.Launcher.addAction(_("Compose New Message"),
-                             wrapCallback(composeNewMessage));
+			     wrapCallback(composeNewMessage));
 
     selfTest();
 }
@@ -53,3 +58,4 @@ if (isCorrectPage()) {
                  onInit: wrapCallback(messagingIndicatorSetup) });
 
 }
+
